@@ -413,6 +413,8 @@ class InfEngineServer:
             return "NOT RUNNING"
 
     def clean(self):
+        """ Delete useless data. """
+
         self._logger.info(f"Cleaning InfServers...")
 
         config = self._load_config("environment")
@@ -420,7 +422,7 @@ class InfEngineServer:
         count = self._clean(
             self.root_path / INF_ENGINE_PATH_ENGINES,
             self.root_path / INF_ENGINE_LINK_READY,
-            int(config["Clean"]["releases"]),
+            int(config["Clean"]["engines"]),
         )
 
         if count:
@@ -436,8 +438,20 @@ class InfEngineServer:
             self._logger.info(f"Deleted {count} releases.")
 
     def _clean(self, dir: Path, ignore: Path, limit: int = 0) -> int:
-        # TODO
-        pass
+        """ Delete several directories from the passed directory. """
+
+        counter = 0
+
+        if dir.is_dir():
+            for obj in dir.iterdir():
+                if obj != ignore:
+                    if obj.is_dir():
+                        self._logger.info(obj)
+
+                if counter == 0:
+                    break
+
+        return counter
 
     def _clean_multidb(self):
         # TODO
@@ -494,10 +508,9 @@ class InfEngineServer:
 
         engine.install(dldata, dlsources, db_name=db_name)
 
+        self.clean()
         self.restart()
 
-        # TODO: clean and unlock
-
     def delete_dl(self, database_name):
         """ Delete DL databases. """
 
