@@ -152,9 +152,20 @@ class InfEngineServerEngine:
 
         self._logger.info(f"DL data compiled.")
 
-    def install(self, dldata: Path, dlsources: Path = None, aliases: Path = None):
+    def install(
+        self,
+        dldata: Path,
+        dlsources: Path = None,
+        aliases: Path = None,
+        db_name: str = "dldata",
+    ):
         """ Install DL data to InfEngine. """
 
+        self._logger.info(f"Installing database: {db_name}")
+
+        INF_ENGINE_FILE_DLDATA_VAR = f"{db_name}.ie2"
+        INF_ENGINE_LINK_DLDATA_VAR = INF_ENGINE_PATH_DLDATA + INF_ENGINE_FILE_DLDATA_VAR
+
         # dldata_obj = create_temp_dir(self._engine_dir / INF_ENGINE_PATH_DLDATA)
         # dldata_path = Path(dldata_obj.name)
         dldata_path = create_temp_dir(self._engine_dir / INF_ENGINE_PATH_DLDATA)
@@ -189,9 +200,9 @@ class InfEngineServerEngine:
         self._logger.debug(
             f"DL data is a file."
             f" Copying {dldata}"
-            f" to {dldata_path / INF_ENGINE_FILE_DLDATA}"
+            f" to {dldata_path / INF_ENGINE_FILE_DLDATA_VAR}"
         )
-        shutil.copy(dldata, dldata_path / INF_ENGINE_FILE_DLDATA)
+        shutil.copy(dldata, dldata_path / INF_ENGINE_FILE_DLDATA_VAR)
 
         # Install DL data sources
         if dlsources:
@@ -224,7 +235,7 @@ class InfEngineServerEngine:
             self._engine_dir
             / INF_ENGINE_PATH_DLDATA
             / dldata_path
-            / INF_ENGINE_FILE_DLDATA
+            / INF_ENGINE_FILE_DLDATA_VAR
         )
         self._logger.debug(
             f"Creating a symlink from {symlink_from}"
@@ -232,58 +243,59 @@ class InfEngineServerEngine:
         )
         symlink(
             symlink_from,
-            self._engine_dir / INF_ENGINE_LINK_DLDATA,
+            self._engine_dir / (INF_ENGINE_PATH_DLDATA + INF_ENGINE_FILE_DLDATA_VAR),
             force=True,
         )
 
-        if Path(dldata_path / INF_ENGINE_PATH_DLSOURCES).is_file():
-            symlink_from = (
-                self._engine_dir
-                / INF_ENGINE_PATH_DLDATA
-                / dldata_path
-                / INF_ENGINE_PATH_DLSOURCES
-            )
-            self._logger.debug(
-                f"Creating a symlink from {symlink_from}"
-                f" to {self._engine_dir / INF_ENGINE_LINK_DLSOURCES}"
-            )
-            symlink(
-                self._engine_dir
-                / INF_ENGINE_PATH_DLDATA
-                / dldata_path
-                / INF_ENGINE_PATH_DLSOURCES,
-                self._engine_dir / INF_ENGINE_LINK_DLSOURCES,
-                force=True,
-            )
-        else:
-            self._logger.debug(
-                f"Removing file {self._engine_dir / INF_ENGINE_LINK_DLSOURCES}"
-            )
-            if Path(self._engine_dir / INF_ENGINE_LINK_DLSOURCES).is_file():
-                Path(self._engine_dir / INF_ENGINE_LINK_DLSOURCES).unlink()
+        if db_name == "dldata":
+            if Path(dldata_path / INF_ENGINE_PATH_DLSOURCES).is_file():
+                symlink_from = (
+                    self._engine_dir
+                    / INF_ENGINE_PATH_DLDATA
+                    / dldata_path
+                    / INF_ENGINE_PATH_DLSOURCES
+                )
+                self._logger.debug(
+                    f"Creating a symlink from {symlink_from}"
+                    f" to {self._engine_dir / INF_ENGINE_LINK_DLSOURCES}"
+                )
+                symlink(
+                    self._engine_dir
+                    / INF_ENGINE_PATH_DLDATA
+                    / dldata_path
+                    / INF_ENGINE_PATH_DLSOURCES,
+                    self._engine_dir / INF_ENGINE_LINK_DLSOURCES,
+                    force=True,
+                )
+            else:
+                self._logger.debug(
+                    f"Removing file {self._engine_dir / INF_ENGINE_LINK_DLSOURCES}"
+                )
+                if Path(self._engine_dir / INF_ENGINE_LINK_DLSOURCES).is_file():
+                    Path(self._engine_dir / INF_ENGINE_LINK_DLSOURCES).unlink()
 
-        if Path(dldata_path / INF_ENGINE_FILE_ALIASES).is_file():
-            symlink_from = (
-                self._engine_dir
-                / INF_ENGINE_PATH_DLDATA
-                / dldata_path
-                / INF_ENGINE_FILE_ALIASES
-            )
-            self._logger.debug(
-                f"Creating a symlink from {symlink_from}"
-                f" to {self._engine_dir / INF_ENGINE_LINK_ALIASES}"
-            )
-            symlink(
-                symlink_from,
-                self._engine_dir / INF_ENGINE_LINK_ALIASES,
-                force=True,
-            )
-        else:
-            self._logger.debug(
-                f"Removing file {self._engine_dir / INF_ENGINE_LINK_ALIASES}"
-            )
-            if Path(self._engine_dir / INF_ENGINE_LINK_DLSOURCES).is_file():
-                Path(self._engine_dir / INF_ENGINE_LINK_DLSOURCES).unlink()
+            if Path(dldata_path / INF_ENGINE_FILE_ALIASES).is_file():
+                symlink_from = (
+                    self._engine_dir
+                    / INF_ENGINE_PATH_DLDATA
+                    / dldata_path
+                    / INF_ENGINE_FILE_ALIASES
+                )
+                self._logger.debug(
+                    f"Creating a symlink from {symlink_from}"
+                    f" to {self._engine_dir / INF_ENGINE_LINK_ALIASES}"
+                )
+                symlink(
+                    symlink_from,
+                    self._engine_dir / INF_ENGINE_LINK_ALIASES,
+                    force=True,
+                )
+            else:
+                self._logger.debug(
+                    f"Removing file {self._engine_dir / INF_ENGINE_LINK_ALIASES}"
+                )
+                if Path(self._engine_dir / INF_ENGINE_LINK_DLSOURCES).is_file():
+                    Path(self._engine_dir / INF_ENGINE_LINK_DLSOURCES).unlink()
 
     def version(self):
         """ Get InfServer version. """
